@@ -38,7 +38,7 @@ my $default_data_type_profiles = {
 	tinyint		=> [ 'number', 'int' ],
 	mediumint	=> [ 'number', 'int' ],
 	bigint		=> [ 'number', 'int' ],
-	decimal		=> [ 'number', 'int' ],
+	decimal		=> [ 'number' ],
 	datetime	=> [ 'datetime' ],
 	timestamp	=> [ 'datetime' ],
 	date		=> [ 'date' ],
